PredictedItem class

An object that identifies an item.

The and APIs return a list of PredictedItems.

Constructors

PredictedItem({String? itemId, double? score})
PredictedItem.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
itemId → String?
The recommended item ID.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → double?
A numeric representation of the model's certainty that the item will be the next user selection. For more information on scoring logic, see how-scores-work.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited